#
# spec file for package tio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tio
Version:        3.8
Release:        1.1
Summary:        Simple TTY terminal I/O application
License:        GPL-2.0-or-later
Group:          Hardware/Modem
URL:            https://tio.github.io/
Source:         https://github.com/tio/tio/releases/download/v%{version}/%{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  lua53-devel
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)

%description
Tio is a simple TTY terminal application which features a straightforward
commandline interface to easily connect to TTY devices for basic input/output.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Hardware/Modem
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for %{name}.

%prep
%setup -q

%build
%meson -Dbashcompletiondir=%{_datadir}/bash-completion/completions/
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc AUTHORS NEWS README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Sat Nov 30 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.8
  * Clean up lua API.
  * Rename modem_send() to send().
  * Rename send to write().
  * Zero initialize buffer in read_string().
  * Fix memory leak in base62_encode().
  * Fix name declaration conflict with socket send().
  * Add clang-format spec.
  * Add system timestamps to lua read() and new lua read_line() per
    global options.
  * Add missing timestamp-format epoch.
  * Update send_ to use fsync and tcdrain like normal tty_sync
    does.
  * Rework read_line to save partial line at timeout.
  * Simplified read_line to reduce cyclomatic complexity.
  * renamed example files read.lua and read_line.lua.
  * moved #define READ_LINE_SIZE to top of file.
  * renamed g_linebuf to linebuf, and moved it into read_line as
    a static variable.
* Sat Aug 31 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.7
  * Remove unnecessary sync in line input mode.
  * Fix socket send call on platforms without MSG_NOSIGNAL.
  * Add "epoch" timestamp option.
  * Fix log-directory options is not read from the configuration
    file.
* Sat Jul 20 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.6
  * Add configuration file include directive.
  * Mention how to list key commands in help output.
  * Fix hex output mode when using normal input mode.
  * Improve warning upon failing connect.
  * Add device path to warning when connect fails.
  * Print correct 'Done' timestamp for X- and Y-modem transfers.
  * Call tio_printf() after completing xymodem_send().
* Sat Jun 29 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.5
  * Clarify input and output direction of map flags.
  * Rename mapping flag MSB2LSB to IMSB2LSB.
  * Add OIGNCR mapping flag.
  * Ignores CR on output to serial device.
  * Fix line input mode ignoring characters ABCD.
  * Fix tainted print.
* Sat Jun 15 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.4
  * Update configuration output.
  * Clean up script run interaction text.
  * Fix unbounded writes.
  * Add history and editing feature to line input mode.
  * Use up and down arrow keys to navigate history.
  * Use left and right arrow keys to move cursor back and forth.
  * We try mimic the behaviour of GNU readline which we can not
    use because.
  * Reuse socket address.
  * Fix line input mode.
  * Fix so that ABCD are no longer ignored.
  * Make sure ICRNL, IGNCR, INLCR take effect.
  * Include correct header for poll().
  * Add group write permission to xymodem received file.
  * Fix missing open() flags in xymodem_receive().
  * Show current mappings in the configuration printout.
  * Use "ctrl-t m" to change mappings interactively.
  * Prompt for Lua script or shell command in interactive session.
  * Added support to receive XMODEM-CRC files from the connected
    serial port.
* Thu May 16 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.3
  * Force destructive backspace when using local echo
  * Only takes effect in normal output mode.
  * Fix local-echo in configuration file
  * Clean up includes
  * Force socket write operation to ignore any signals
  * Man page cleanup
* Thu May  9 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.2
  * Do not print error when using --list with broken config file
  * Clean up completion script
  * Add option '--exec ' for running shell command
  * Runs shell command with I/O redirected to device.
  * Make sure all error output is directed to stderr
  * Fix shadow variables
  * Update man page
  * Fix build on older GNU/Linux systems without statx
  * Fix line ending in --list output
  * Print location of configuratin file in --list output
  * Fix alignment of profile listing
- Update to version 3.1
  * Improve --list feature on non-linux platform
  * List available profiles in --list output
  * Always message when saving log file
  * Add support for using TID as device in config file
  * Fix use of invalid flag with regexec()
  * Fix potential buffer overflow in match_and_replace()
  * Fix profile autocompletion
  * Replace use of stat() with fstat()
  * For better security.
  * Fix hexN output mode
  * Update pattern matching example
  * Fix submenu response when invalid key hit
  * Replace inih with glib key file parser
  * Enable extended pattern matching
  * Update lua read() description
* Mon Apr 29 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0
  * Simplify lua line manipulation API
  * Disable DEC Special Graphics at exit if vt100
  * Add hexN output mode
  * Rename sub-config to profile
  * Use lua io.write() instead of print()
  * Add new ways to manage serial devices
    + Rename --list-devices to --list
    + Rename --no-autoconnect to --no-reconnect
    + Switch -l and -L options
  - l now lists available serial devices
  - L enables log to file
    + Add option --auto-connect
    + Connect to same port/device combination via unique
    topology ID (TID)
    + Reworked and improved listing of serial devices to show
    serial devices
  * Clean up timestamp enum definition
  * Add missing options to show configuration
  * Update description of mute option
  * Add lua read_string() function
  * Don't forget to log output in lua expect()
  * Generalize automatic login example for Linux
  * Fix log output in hex output mode
  * Add timeout based timestamps in hex output mo
  * Improve switched messages
  * Extend lua expect() to also return matched string
  * Add automatic login script example
  * Organize examples directory
  * Introduce basic line input mode
  * Cleanup global variable name shadowing
  * Updated login example with new expect logic
  * Reset buffer size at start of expect
* Sun Apr 14 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8
  * Remove options --response-wait, --response-timeout
  * Fix xymodem error print outs
  * Rework x/y-modem transfer command
  * Add independent input and output mode
  * Add tty line configuration script API
  * Add ONULBRK mapping flag
  * Add --log-directory option
  * Add Lua scripting feature
  * Poll on serial port read instead of delay.
  * Add Xmodem-CRC support.
  * Support NO_COLOR env variable as per no-color.org
  * Add map FF to ESC-c on input
* Thu Sep 21 2023 Martin Hauke <mardnh@gmx.de>
- Update to 2.7:
  * Add xmodem and ymodem file send support
  * fix: support --log-append in cli options
* Sat Jun 10 2023 Martin Hauke <mardnh@gmx.de>
- Update to 2.6:
  * Remove warning when using pattern option
  * Add --log-append option
  * Fix line termination for response wait feature
* Wed Dec 28 2022 Dirk Müller <dmueller@suse.com>
- update to 2.5:
  * Update configuration file documentation
    Rename .tiorc to .tioconfig, tiorc to config, etc.
  * Add support for $HOME/.tioconfig
    Replaces what used to be $HOME/.tiorc
  * Fix double prefix key regression
  * Better error checking in config file, rename the file
    Accept "true", "enable", "on", "yes", "1" as true values, their
    counterparts as false ones. Check integer values for errors and range.
    Warn about ignored (e.g. misspelled) options.
    Check getenv() return value for NULL.
    Rename "tiorc" to "config", as it's a static INI file, not an executable
    "run commands".
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.4:
  * Add threaded input handling
  * Fix so that is it possible to quit tio in tio etc.
  * Add key command to toggle log on/off
* Sun Nov  6 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3
  * Add mute feature
  * Deprecate tty config keyword but keep it around for now
  * Update show config
  * Update example tiorc
* Thu Oct 20 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2
  * Add shell completion of sub-configuration names
  * Does not work with sub configuration names that contains one
    or more white spaces.
* Sat Oct 15 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1
  * Fix output line delay
  * Apply output line delay on lines ending with \n.
  * On most systems lines ends with \n or \r\n.
  * Do not print timestamps in hex mode
  * Improve input mechanism in hex mode
  * Add support for sending prefix character to serial device
  * Update example tiorc
* Sun Sep 11 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0
  * Handle stale unix socket file
  * Add visual or audible alert support on connect/disconnect
  * Add experimental RS-485 support
  * Add line response feature
  * Fix potential sscanf() overflow
  * Only print version on '--version'
  * Remove duplicate show config entry of DTR pulse duration
- Update to version 1.47
  * Enable log feature when using --log-filename
  * Enable line buffering of log
  * Avoid invalid hex character messages when switching hex mode
  * Force flushing of log writes
  * Renamed tty_flush() to tty_sync()
  * Fix sync output to serial port
  * Clean up tty_flush()
  * Force frequent sync on tty_flush()
  * Update example tiorc
  * Quit from non-interactive mode using ctrl-c
  * Make sure we flush output buffer to tty when piping to tio
  * Do not return false read error when piping to tio
  * Show error message when reading port settings fail
- Update to version 1.46
  * Rework toggle and pulse feature to support all lines
  * Add example configuration file
- Update to version 1.45
  * Introduce bold color option
  * Change 'ctrl-t T' to 'ctrl-t t' for timestamp toggle
  * Add support for remapping prefix key
  * Add plaintext man page
- Update to version 1.44
  * Simplify arbitrary baudrate code
  * Cleanup error printing routines
  * Clean up man page
  * Add support for space parity
  * Rename EOL delay to Output line delay
  * Replace -U,--upcase with mapping flag OLTU
  * Simplify tty_write()
  * Additional commands: EOL delay, lower to upper translation,
    added mark parity
  * Added ability to set mark parity.
- Update to version 1.43
  * Add '24hour-delta' timestamp option
  * Improve description of socket option
  * Add Pulse DTR command
* Tue Jul  5 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.42
  * Update man page
  * Handle malloc failure
  * Add missing 'string.h' include.
* Mon Jul  4 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.41
  * Rename --hex-mode to --hexadecimal
  * Enable buffered writing / reading
* Sat Jun 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.40
  * Add config support for log-strip
  * Add config support for hex-mode
  * Rename --hex to --hex-mode
  * Fix completion for -e, --local-echo
  * Ignore newlines in hex output
  * Fix newline in warning_printf()
  * Fix ansi_printf_raw() in no color mode
  * Enter non-interactive mode when piping to tio
  * Also strip backspace from log
  * Socket code cleanup
  * Cleanup man page
  * Rename --log-filename to --log-file
  * Allow strip escape sequence characters from log file
- Update to version 1.39
  * Improve key command response for local echo and timestamp
  * Fix invalid hex character error message
  * Make sure only matched config section is parsed
  * Add support for "disable" keyword in config file
  * Unify error message formating
  * Cleanup list devices code
  * Fix command-line tty-device|config parsing
  * Update bash completion
  * Add support for IPv4 and IPv6 network sockets
  * Fix tio deleting unix socket file
  * Rework color option
  * Remove print of hex mode status at startup
  * Remove newline option in hex mode
  * Fix configfile memory leaks
  * Remove command-line option inconsistencies
  * Replace '1' with 'enable' in config files
  * Convert errors to warnings
  * Extended hexadecimal mode.
  * Added option -x, --hex to start in hexadecimal mode.
* Thu Jun  2 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.38
  * Redirect error messages to stderr
  * Improve help and man page
  * Mention config file in --help
  * Fix running without config file
  * Fix config file error messages
  * Redirect error messages to stderr
  * Add repology packaging status
  * Fix parsing of default settings
  * Default configuration file settings were not parsed in case a
    section was matched. Now we make sure that the default
    (unnamed) settings are always parsed.
  * Append to existing log file (no truncation)
  * Add socket info to show configuration
  * Print socket info at startup
  * Fix socket option parsing
  * Match user input against config section names if pattern
    matching was unsuccessful.
  * Add support for external control via a Unix domain socket.
  * fix for using option 'log' without 'log-filename' in config
    file.
* Wed Apr 13 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.37
  * Make libinih a fallback dependency
  * Fix timestamp parsing in INI conf
  * Factorize timestamp parsing to be coherent with command line
    format in configuration file.
* Wed Mar 23 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.36
  * Add support for defaults in config file
  * Handle SIGHUP
  * Add color configuration support
  * Force dependency on libinih
  * Update man page
  * Document configuration file options
  * Add support for a configuration file
- Update to version 1.35
  * Add support for automatically generated log filename
  * Add support for configurable timestamp format
* Tue Feb 15 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.34
  * Add '-c, --color' option
  * Reintroduce long timestamp format
* Sun Feb 13 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.33
  * Replace autotools with meson
  * Show auto connect status in show configuration
  * Rename option -i to -L
  * Shorten timestamp description
  * Add list serial devices feature
  * Add command to show version
  * Add '-t' option description for time stamping
  * Add description for time stamping.
  * Show error when failing to open a tty
  * Newline: handle booth NL and CR
  * Flush every local echo char
* Tue Jan 11 2022 Martin Hauke <mardnh@gmx.de>
- Run spec-cleaner
- Create subpackage for bash-completion
* Fri Jan  1 2021 Stefan Siegel <ssiegel@sdas.net>
- Initial package
